@@ -18,6 +18,12 @@
 #include "magic.h"
 
 
+/** Internal video-encoder format */
+#ifndef VIDENC_INTERNAL_FMT
+#define VIDENC_INTERNAL_FMT (VID_FMT_YUV420P)
+#endif
+
+
 enum {
 	SRATE = 90000,
 	MAX_MUTED_FRAMES = 3,
@@ -223,13 +229,13 @@ static void encode_rtp_send(struct vtx *vtx, struct vidframe *frame)
 	lock_write_get(vtx->lock);
 
 	/* Convert image */
-	if (frame->fmt != VID_FMT_YUV420P) {
+	if (frame->fmt != VIDENC_INTERNAL_FMT) {
 
 		vtx->vsrc_size = frame->size;
 
 		if (!vtx->frame) {
 
-			err = vidframe_alloc(&vtx->frame, VID_FMT_YUV420P,
+			err = vidframe_alloc(&vtx->frame, VIDENC_INTERNAL_FMT,
 					     &vtx->vsrc_size);
 			if (err)
 				goto unlock;
@@ -677,7 +683,7 @@ static int set_encoder_format(struct vtx *vtx, const char *src,
 	}
 
 	vtx->mute_frame = mem_deref(vtx->mute_frame);
-	err = vidframe_alloc(&vtx->mute_frame, VID_FMT_YUV420P, size);
+	err = vidframe_alloc(&vtx->mute_frame, VIDENC_INTERNAL_FMT, size);
 	if (err)
 		return err;
 
